@@ -12,7 +12,7 @@ use Perinci::Sub::Util qw(gen_modified_sub);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-08-20'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.288'; # VERSION
+our $VERSION = '0.289'; # VERSION
 
 our %SPEC;
 
@@ -929,13 +929,13 @@ _
                 argv => ['wt_S_'],
                 summary => 'One guess (lowercase means incorrect position)',
                 test => 0,
-                'x.doc.show_result' => 0,
+                'x.doc.show_result' => 1,
             },
             {
                 argv => ['___s_', '_o___', '___ht', '_L___'],
-                summary => 'For guesses (lowercase means incorrect position)',
+                summary => 'Four guesses (lowercase means incorrect position)',
                 test => 0,
-                'x.doc.show_result' => 0,
+                'x.doc.show_result' => 1,
             },
         ];
     },
@@ -985,7 +985,7 @@ App::wordlist - Grep words from (or test them against) WordList::*
 
 =head1 VERSION
 
-This document describes version 0.288 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
+This document describes version 0.289 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
 
 =head1 SYNOPSIS
 
@@ -1250,10 +1250,128 @@ Examples:
 
  wordlist_wordle(arg => ["wt_S_"]);
 
-=item * For guesses (lowercase means incorrect position):
+Result:
+
+ [
+   200,
+   "OK",
+   sub {
+     REDO: return if $i_wordlist >= @$wordlists;
+     my $wl = $$wordlists[$i_wordlist];
+     unless ($wl_obj) {
+     log_trace("Instantiating wordlist $wl ...");
+     eval {
+     do {
+     $wl_obj = Module::Load::Util::instantiate_class_with_optional_args({'ns_prefix', 'WordList'}, $wl)
+     }
+     };
+     warn if $@;
+     unless ($wl_obj) {
+     ++$i_wordlist;
+     goto REDO;
+     }
+     $nth_word = 0;
+     }
+     my $word = $nth_word++ ? $wl_obj->next_word : $wl_obj->first_word;
+     unless (defined $word) {
+     undef $wl_obj;
+     ++$i_wordlist;
+     goto REDO;
+     }
+     goto REDO if not $random and $num > 0 and $n >= $num;
+     goto REDO if defined $args{'len'} and _length_in_graphemes($word) != $args{'len'};
+     goto REDO if defined $args{'min_len'} and _length_in_graphemes($word) < $args{'min_len'};
+     goto REDO if defined $args{'max_len'} and _length_in_graphemes($word) > $args{'max_len'};
+     goto REDO if defined $args{'chars_unordered'} and not _word_has_chars_unordered($word, $args{'chars_unordered'}, $ci);
+     goto REDO if defined $args{'chars_ordered'} and not _word_has_chars_ordered($word, $args{'chars_ordered'}, $ci);
+     my $cmpword = $ci ? lc $word : $word;
+     my $match_arg;
+     foreach $_ (@$arg) {
+     my $match = ref $_ eq 'Regexp' ? $cmpword =~ /$_/ : index($cmpword, $_) != -1;
+     if ($or) {
+     if ($match) {
+     ++$n;
+     return &$code_format_word($wl, $word, $use_color ? $_ : undef, $ci);
+     }
+     }
+     else {
+     unless ($match) {
+     goto REDO;
+     }
+     }
+     $match_arg = $_;
+     }
+     if (not $or && @$arg) {
+     ++$n;
+     return &$code_format_word($wl, $word, $use_color ? $match_arg : undef, $ci);
+     }
+   },
+   { stream => 1 },
+ ]
+
+=item * Four guesses (lowercase means incorrect position):
 
  wordlist_wordle(arg => ["___s_", "_o___", "___ht", "_L___"]);
 
+Result:
+
+ [
+   200,
+   "OK",
+   sub {
+     REDO: return if $i_wordlist >= @$wordlists;
+     my $wl = $$wordlists[$i_wordlist];
+     unless ($wl_obj) {
+     log_trace("Instantiating wordlist $wl ...");
+     eval {
+     do {
+     $wl_obj = Module::Load::Util::instantiate_class_with_optional_args({'ns_prefix', 'WordList'}, $wl)
+     }
+     };
+     warn if $@;
+     unless ($wl_obj) {
+     ++$i_wordlist;
+     goto REDO;
+     }
+     $nth_word = 0;
+     }
+     my $word = $nth_word++ ? $wl_obj->next_word : $wl_obj->first_word;
+     unless (defined $word) {
+     undef $wl_obj;
+     ++$i_wordlist;
+     goto REDO;
+     }
+     goto REDO if not $random and $num > 0 and $n >= $num;
+     goto REDO if defined $args{'len'} and _length_in_graphemes($word) != $args{'len'};
+     goto REDO if defined $args{'min_len'} and _length_in_graphemes($word) < $args{'min_len'};
+     goto REDO if defined $args{'max_len'} and _length_in_graphemes($word) > $args{'max_len'};
+     goto REDO if defined $args{'chars_unordered'} and not _word_has_chars_unordered($word, $args{'chars_unordered'}, $ci);
+     goto REDO if defined $args{'chars_ordered'} and not _word_has_chars_ordered($word, $args{'chars_ordered'}, $ci);
+     my $cmpword = $ci ? lc $word : $word;
+     my $match_arg;
+     foreach $_ (@$arg) {
+     my $match = ref $_ eq 'Regexp' ? $cmpword =~ /$_/ : index($cmpword, $_) != -1;
+     if ($or) {
+     if ($match) {
+     ++$n;
+     return &$code_format_word($wl, $word, $use_color ? $_ : undef, $ci);
+     }
+     }
+     else {
+     unless ($match) {
+     goto REDO;
+     }
+     }
+     $match_arg = $_;
+     }
+     if (not $or && @$arg) {
+     ++$n;
+     return &$code_format_word($wl, $word, $use_color ? $match_arg : undef, $ci);
+     }
+   },
+   { stream => 1 },
+ ]
+
 =back
 
 This is a wrapper to L<wordlist> designed to be a convenient helper to solve
